@@ -15,7 +15,7 @@ import os
 import sys
 from configparser import NoOptionError, NoSectionError
 from functools import wraps
-from typing import Tuple, Union
+from typing import Union
 from urllib.parse import urljoin
 
 import requests
@@ -44,10 +44,11 @@ MSG_JSON_DECODE_ERROR = (
     " more information"
 )
 MSG_HTTP_ERROR = (
-    "Unable to access the api. Try running again with the --debug command line argument for"
+    "An error occurred when accessing the api. Try running again with the --debug command line argument for"
     " more information"
 )
 
+
 logger = get_logger(__name__)
 
 
@@ -147,35 +148,23 @@ class CliOsduClient(OsduClient):
             ok_status_codes (list, optional): Status codes for successful call. Defaults to [200].
         """
         url = self._url_from_config(config_url_key, url_extra_path)
-        if ok_status_codes is None:
-            ok_status_codes = [200]
         response = self.get(url)
-        if response.status_code not in ok_status_codes:
+        if ok_status_codes is not None and response.status_code not in ok_status_codes:
             raise HTTPError(response=response)
         return response
 
-    def cli_get_returning_json(self, config_url_key: str, url_extra_path: str) -> dict:
+    def cli_get_returning_json(
+        self, config_url_key: str, url_extra_path: str, ok_status_codes: list = None
+    ) -> dict:
         """[summary]
 
         Args:
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
+            ok_status_codes (list, optional): accepted ok response codes. Defaults to None.
         """
-        response = self.cli_get(config_url_key, url_extra_path)
-        try:
-            return response.json()
-        except HTTPError as ex:
-            logger.error(MSG_HTTP_ERROR)
-            logger.error("Error (%s) - %s", ex.response.status_code, ex.response.reason)
-        except ValueError as ex:
-            logger.error(MSG_JSON_DECODE_ERROR)
-            logger.debug(ex)
-        except (NoOptionError, NoSectionError) as ex:
-            logger.warning(
-                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
-            )
-
-        sys.exit(1)
+        url = self._url_from_config(config_url_key, url_extra_path)
+        return self.get_returning_json(url, ok_status_codes)
 
     def cli_post_returning_json(
         self,
@@ -183,7 +172,7 @@ class CliOsduClient(OsduClient):
         url_extra_path: str,
         data: Union[str, dict],
         ok_status_codes: list = None,
-    ):
+    ) -> dict:
         """[summary]
 
         Args:
@@ -193,24 +182,10 @@ class CliOsduClient(OsduClient):
             ok_status_codes (list, optional): Status codes indicating successful call. Defaults to [200].
 
         Returns:
-            [type]: [description]
+            dict: returned json
         """
-        try:
-            url = self._url_from_config(config_url_key, url_extra_path)
-            return self.post_returning_json(url, data, ok_status_codes)
-        except HTTPError as ex:
-            logger.error(MSG_HTTP_ERROR)
-            logger.debug(ex.response.text)
-            logger.error("Error (%s) - %s", ex.response.status_code, ex.response.reason)
-        except ValueError as ex:
-            logger.error(MSG_JSON_DECODE_ERROR)
-            logger.debug(ex)
-        except (NoOptionError, NoSectionError) as ex:
-            logger.warning(
-                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
-            )
-
-        sys.exit(1)
+        url = self._url_from_config(config_url_key, url_extra_path)
+        return self.post_returning_json(url, data, ok_status_codes)
 
     def cli_delete(
         self,
@@ -246,67 +221,43 @@ class CliOsduClient(OsduClient):
 
         sys.exit(1)
 
-        # # loop for implementing retries send process
-        # retries = config.getint("CONNECTION", "retries")
-        # for retry in range(retries):
-        #     try:
-
-        #         if response.status_code in DATA_LOAD_OK_RESPONSE_CODES:
-        #             workflow_response = response.json()
-        #             logger.info(f"Response: {workflow_response}")
-        #             file_logger.info(f"{workflow_response.get('runId')}")
-        #             break
-
-        #         reason = response.text[:250]
-        #         logger.error(f"Request error.")
-        #         logger.error(f"Response status: {response.status_code}. "
-        #                     f"Response content: {reason}.")
-
-        #         if retry + 1 < retries:
-        #             if response.status_code in BAD_TOKEN_RESPONSE_CODES:
-        #                 logger.error(f"Error in Request: {headers.get('correlation-id')})")
-        #             else:
-        #                 time_to_sleep = config.getint("CONNECTION", "timeout")
-
-        #                 logger.info(f"Retrying in {time_to_sleep} seconds...")
-        #                 time.sleep(time_to_sleep)
-
-        #     except (requests.RequestException, HTTPError) as exc:
-        #         logger.error(f"Unexpected request error. Reason: {exc}")
-        #         sys.exit(2)
-
     def cli_put(
         self,
-        url: str,
-        # config_url_key: str,
-        # url_extra_path: str,
-        filepath: str,
-    ) -> Tuple[requests.Response, dict]:
-        """PUT the file at the given path to the given url.
-        Includes common CLI specific error handling
+        config_url_key: str,
+        url_extra_path: str,
+        data: Union[str, dict],
+        ok_status_codes: list = None,
+    ) -> requests.Response:
+        """[summary]
 
         Args:
             config_url_key (str): key in configuration for the base path
             url_extra_path (str): extra path to add to the base path
-            filepath (str): path to a file to PUT
+            ok_status_codes (list, optional): Status codes for successful call. Defaults to [200].
+        """
+        url = self._url_from_config(config_url_key, url_extra_path)
+        response = self.put(url, data)
+        if ok_status_codes is not None and response.status_code not in ok_status_codes:
+            raise HTTPError(response=response)
+        return response
+
+    def cli_put_returning_json(
+        self,
+        config_url_key: str,
+        url_extra_path: str,
+        data: Union[str, dict],
+        ok_status_codes: list = None,
+    ) -> dict:
+        """PUT the data to the given url.
+
+        Args:
+            config_url_key (str): key in configuration for the base path
+            url_extra_path (str): extra path to add to the base path
+            data (Union[str, dict]): data to send
+            ok_status_codes (list, optional): accepted ok response codes. Defaults to None.
 
         Returns:
-            Tuple[requests.Response, dict]: Turle with response object and returned json
+            dict: returned json
         """
-        try:
-            # url = CliOsduClient._url_from_config(config_url_key, url_extra_path)
-            response = self.put(url, filepath)
-            if response.status_code in [200]:
-                return response, response.json()
-
-            logger.error(MSG_HTTP_ERROR)
-            logger.error("Error (%s) - %s", response.status_code, response.reason)
-        except ValueError as ex:
-            logger.error(MSG_JSON_DECODE_ERROR)
-            logger.debug(ex)
-        except (NoOptionError, NoSectionError) as ex:
-            logger.warning(
-                "Configuration missing from config ('%s'). Run 'osdu config update'", ex.args[0]
-            )
-
-        sys.exit(1)
+        url = self._url_from_config(config_url_key, url_extra_path)
+        return self.put_returning_json(url, data, ok_status_codes)
