@@ -16,7 +16,7 @@ import configparser
 
 import click
 
-from osducli.click_cli import State, global_params
+from osducli.click_cli import CustomClickCommand, State, global_params
 from osducli.cliclient import handle_cli_exceptions
 from osducli.commands.config.consts import (
     AUTHENTICATION_LIST,
@@ -76,7 +76,7 @@ from osducli.util.prompt import prompt, prompt_choice_list, prompt_y_n
 # from osducli.util import is_help_command
 
 
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-k", "--key", help="A specific key to update.")
 @click.option("-v", "--value", help="Value to update key with.")
 @global_params
