@@ -18,7 +18,7 @@ import os
 import click
 import requests
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.commands.dataload.status import check_status
 from osducli.commands.dataload.verify import batch_verify
@@ -40,11 +40,11 @@ VERIFY_BATCH_SIZE = 200
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option(
     "-p",
     "--path",
-    help="Path to a file or files to ingest.",
+    help="Path to a manifest file or files to ingest.",
     type=click.Path(exists=True, file_okay=True, dir_okay=True, readable=True, resolve_path=True),
     required=True,
 )
@@ -88,7 +88,11 @@ def _click_command(
     skip_existing: str = False,
     simulate: bool = False,
 ):
-    """Ingest files into OSDU."""
+    """Ingest manifest files into OSDU.
+
+    This command will take existing manfiest files and load them into OSDU via the workflow
+    service and Airflow. 'legal' and 'acl' tags will be updated based upon the current
+    configuration"""
     return ingest(state, path, files, batch, runid_log, wait, skip_existing, simulate)
 
 
@@ -102,7 +106,7 @@ def ingest(
     skip_existing: bool = False,
     simulate: bool = False,
 ) -> dict:
-    """Ingest files into OSDU
+    """Ingest manifest files into OSDU
 
     Args:
         state (State): Global state
