@@ -17,7 +17,7 @@ import time
 
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_WORKFLOW_URL, CLIConfig
 from osducli.log import get_logger
@@ -34,7 +34,7 @@ logger = get_logger(__name__)
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-r", "--runid", help="Runid to query status of.")
 @click.option(
     "-rl",
