@@ -15,15 +15,15 @@
 import click
 from osdu.search import SearchClient
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.argument("id")
 @handle_cli_exceptions
-@command_with_output(None)
+@command_with_output("results[*]")
 def _click_command(state: State, id: str):  # noqa:W1 pylint: disable=invalid-name,redefined-builtin
     """Search for the specified id"""
     return query(state, id)
