@@ -15,16 +15,16 @@
 import click
 from osdu.search import SearchClient
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @click.option("-k", "--kind", "kind", help="kind to search for")
 @click.option("-id", "--id", "_id", help="id to search for")
 @handle_cli_exceptions
-@command_with_output(None)
+@command_with_output("results[*].{Id:id,Kind:kind,CreateTime:createTime}")
 def _click_command(state: State, kind: str, _id: str):
     """Query search service"""
     return query(state, kind, _id)
