@@ -17,12 +17,12 @@ import sys
 import click
 
 import osducli
-from osducli.click_cli import global_params
+from osducli.click_cli import CustomClickCommand, global_params
 from osducli.cliclient import handle_cli_exceptions
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @handle_cli_exceptions
 @global_params
 def _click_command(_):
