@@ -14,13 +14,13 @@
 
 import click
 
-from osducli.click_cli import State, command_with_output
+from osducli.click_cli import CustomClickCommand, State, command_with_output
 from osducli.cliclient import CliOsduClient, handle_cli_exceptions
 from osducli.config import CONFIG_WORKFLOW_URL
 
 
 # click entry point
-@click.command()
+@click.command(cls=CustomClickCommand)
 @handle_cli_exceptions
 @command_with_output(None)
 def _click_command(state: State) -> dict:
